@@ -4,7 +4,8 @@
 #include <Rcpp.h>
 Rcpp::DataFrame payload_parse_activity2_26C(
     Rcpp::RawVector payload, int samp_rate,
-    int scale_factor, bool is_last_packet
+    int scale_factor, bool is_last_packet,
+    Rcpp::Datetime timestamp
 );
 
 #endif
