@@ -20,6 +20,17 @@ testthat::test_that("File reading produces expected output", {
       ),
       output_vars = c("gyroscope", "magnetometer")
     )[ ,-2],
-    "IMU_read_cache.rds"
+    "IMU_read_cache_1.rds"
   )
+
+  testthat::expect_equal_to_reference(
+    suppressMessages(read_AG_IMU(
+      system.file(
+        "extdata", "example-IMU.csv", package = "AGread"
+      ), 5,
+      output_vars = c("gyroscope", "magnetometer")
+    )[ ,-2]),
+    "IMU_read_cache_5.rds"
+  )
+
 })
