@@ -55,13 +55,12 @@ testthat::test_that(
 
       testthat::expect_true(
         all(PAutilities::test_errors(
-          AG, test1, accel_vars
+          AG, test1, accel_vars, 0.0001
         ))
       )
 
       testthat::expect_equal(
-        AG, test1,
-        tolerance = 0.0015, scale = 1
+        AG, test1, scale = 1
       )
 
     ## Test 2: gt3x_raw equivalent to read_raw, 1-s epochs? ####
@@ -78,14 +77,13 @@ testthat::test_that(
             AG,
             test2,
             setdiff(names(AG), "Timestamp"),
-            0.1
+            0.0001
           )
         )
       )
 
       testthat::expect_equal(
-        AG, test2,
-        tolerance = 0.1, scale = 1
+        AG, test2, scale = 1
       )
 
     ## Test 3: gt3x_raw equivalent to read_raw, 5-s epochs? ####
@@ -102,14 +100,13 @@ testthat::test_that(
             AG,
             test3,
             setdiff(names(AG), "Timestamp"),
-            0.1
+            0.0001
           )
         )
       )
 
       testthat::expect_equal(
-        AG, test3,
-        tolerance = 0.1, scale = 1
+        AG, test3, scale = 1
       )
 
     ## Test 4: gt3x_imu equivalent to read_imu? ####
@@ -123,13 +120,13 @@ testthat::test_that(
           PAutilities::test_errors(
             AG, test4,
             setdiff(names(AG), "Timestamp"),
-            0.0005
+            0.000001
           )
         )
       )
 
       testthat::expect_equal(
-        AG, test4, tolerance = 0.0005,
+        AG, test4, tolerance = 0.000001,
         scale = 1
       )
 
@@ -139,7 +136,7 @@ testthat::test_that(
       AG <- collapse_gt3x(AG)[seq(nrow(test5)),-c(1:2)]
 
       testthat::expect_equal(
-        AG, test5, tolerance = 0.0005,
+        AG, test5, tolerance = 0.00005,
         scale = 1
       )
 
